@@ -41,6 +41,7 @@ def kill(pid):
 
 class Subprocess(AnyEntity):
     __regid__ = 'Subprocess'
+    envencoding = 'utf-8'
 
     def dc_title(self):
         try:
@@ -65,7 +66,9 @@ class Subprocess(AnyEntity):
     def _environ(self):
         env = os.environ.copy()
         env.update(json.loads(self.env) if self.env else {})
-        return dict((str(k), v) for k, v in env.iteritems())
+        return dict((k.encode(self.envencoding) if isinstance(k, unicode) else k,
+                     v.encode(self.envencoding) if isinstance(v, unicode) else v)
+                    for k, v in env.iteritems())
 
     def _launch(self):
         """Launch a subprocess defined.
@@ -111,7 +114,7 @@ class Subprocess(AnyEntity):
         assert self.cw_adapt_to('IWorkflowable').state == 'in progress'
         def _launch():
             with self._cw.repo.internal_cnx() as cnx: # dedicated cnx in thread
-                return_code = cnx.entity_from_eid(self.eid)._start()
+                cnx.entity_from_eid(self.eid)._start()
         self._cw.repo.threaded_task(_launch)
 
     def synchronousstart(self):
