@@ -17,10 +17,9 @@
 
 """cubicweb-subprocess entity's classes"""
 from cubicweb import ExecutionError
-from psutil.error import NoSuchProcess
 
 __all__ = ('ProcessNotRunning',)
 
-class ProcessNotRunning(NoSuchProcess, ExecutionError):
+class ProcessNotRunning(ExecutionError):
     '''Exception raised when a process with a certain PID doesn't or no
     longer exists.'''
