@@ -15,19 +15,43 @@
 # You should have received a copy of the GNU Lesser General Public License along
 # with this program. If not, see <http://www.gnu.org/licenses/>.
 
-import sys
 import os
 import time
-import psutil
+import json
+import sys
 
 from cubicweb import ValidationError
-from cubes.subprocess.entities import Subprocess
 from cubes.subprocess.error import ProcessNotRunning
 
 from utils import SubprocessTC
 
+def pid_exists(pid):
+    # http://stackoverflow.com/a/17645146
+    if os.name == 'posix':
+        import errno
+        if pid < 0:
+            return False
+        try:
+            os.kill(pid, 0)
+        except OSError as e:
+            return e.errno == errno.EPERM
+        else:
+            return True
+    else:
+        import ctypes
+        kernel32 = ctypes.windll.kernel32
+        SYNCHRONIZE = 0x100000
+
+        process = kernel32.OpenProcess(SYNCHRONIZE, 0, pid)
+        if process != 0:
+            kernel32.CloseHandle(process)
+            return True
+        else:
+            return False
+
 
 class SubprocessEntityTC(SubprocessTC):
+
     def check_subprocess_status(self, retcode, expected_state):
         '''Start a subprocess that returns with ``retcode``.
         Check the db for recorded return code and workflow state.'''
@@ -48,6 +72,15 @@ class SubprocessEntityTC(SubprocessTC):
             self.wait_finished(subprocess)
             self.assertEqual(0, subprocess.return_code)
 
+    def test_unicode_key_in_env_and_synchronousstart(self):
+        with self.admin_access.repo_cnx() as cnx:
+            cmdline = unicode(json.dumps([sys.executable, '-c', 'pass']))
+            os.environ[u'FOO'] = u'BABAR'
+            subprocess = cnx.create_entity('Subprocess', cmdline=cmdline)
+            cnx.commit()
+            subprocess.synchronousstart()
+            self.assertEqual(0, subprocess.return_code)
+
     def test_start_and_succeeds(self):
         self.check_subprocess_status(retcode=0, expected_state=u'succeeded')
 
@@ -72,7 +105,7 @@ class SubprocessEntityTC(SubprocessTC):
             subprocess.kill()
             self.assertLess(time.time() - starttime, 3599) # must be killed quickly
             self.wait_finished(subprocess, 2)
-            self.assertFalse(psutil.pid_exists(subprocess.pid))
+            self.assertFalse(pid_exists(subprocess.pid))
 
     def test_kill_finished(self):
         with self.admin_access.repo_cnx() as cnx:
